pub struct SpiBusMetadata {
pub channels: Option<Vec<SpiChannel>>,
pub bus_id: Option<u32>,
/* private fields */
}Expand description
Passed to the spi driver in platform device metadata.
Fields
channels: Option<Vec<SpiChannel>>bus_id: Option<u32>ID of the bus that these devices are on. Set as a bind property on the nodes added by the SPI core driver.